/*
 * Copyright (C) 2006-2007 Andre Noll <maan@systemlinux.org>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file net.h exported symbols from net.c */

/**
 * the buffer size of the sun_path component of struct sockaddr_un
 *
 * While glibc doesn't define \p UNIX_PATH_MAX, it
 * documents it has being limited to 108 bytes.
 */
#ifndef UNIX_PATH_MAX
#define UNIX_PATH_MAX 108
#endif

/** used to crypt the communication between para_server and para_client */
typedef void crypt_function(unsigned long len,
	const unsigned char *indata, unsigned char *outdata, void *private_data);

#include <netdb.h> /* hostent */
int get_host_info(char *host, struct hostent **ret);
int get_socket(void);
void init_sockaddr(struct sockaddr_in*, int, const struct hostent*);
int para_connect(int, struct sockaddr_in *);
int send_buffer(int, const char *);
int send_bin_buffer(int, const char *, size_t);
__printf_2_3 int send_va_buffer(int fd, const char *fmt, ...);
int recv_buffer(int fd, char *buf, size_t size);
int recv_bin_buffer(int fd, char *buf, size_t size);
int para_accept(int, void *addr, socklen_t size);
int create_local_socket(const char *name, struct sockaddr_un *unix_addr,
	mode_t mode);
int init_unix_addr(struct sockaddr_un *, const char *);
int recv_cred_buffer(int, char *, size_t);
ssize_t send_cred_buffer(int, char*);
int recv_pattern(int fd, const char *pattern, size_t bufsize);
int init_tcp_socket(int port);
void enable_crypt(int fd, crypt_function *recv_f, crypt_function *send_f,
	void *private_data);
void disable_crypt(int fd);

